@@ -92,8 +92,12 @@ gnome_db_browser_tables_show (GtkWidget *widget, GdaConnection *cnc, const gchar
 	GnomeDbBrowserTablesPrivate *priv;
 	GList *reclist;
 	GdaCommand *cmd;
+	GdaDataModel *fields;
+	GdaParameterList *params;
 
 	g_return_if_fail (GTK_IS_WIDGET (widget));
+	g_return_if_fail (GDA_IS_CONNECTION (cnc));
+	g_return_if_fail (str != NULL);
 
 	priv = g_object_get_data (G_OBJECT (widget), "GnomeDbBrowserTablesPrivate");
 	if (!priv)
@@ -101,7 +105,17 @@ gnome_db_browser_tables_show (GtkWidget *widget, GdaConnection *cnc, const gchar
 
 	gnome_db_browser_tables_clear (widget);
 
-	/* execute command on server */
+	/* get table structure */
+	params = gda_parameter_list_new ();
+	gda_parameter_list_add_parameter (params, gda_parameter_new_string ("name", str));
+	fields = gda_connection_get_schema (cnc, GDA_CONNECTION_SCHEMA_FIELDS, params);
+
+	gnome_db_grid_set_model (GNOME_DB_GRID (priv->table_struct), fields);
+
+	gda_parameter_list_free (params);
+	g_object_unref (G_OBJECT (fields));
+	
+	/* get table data */
 	cmd = gda_command_new (str, GDA_COMMAND_TYPE_TABLE, 0);
 	reclist = gda_connection_execute_command (cnc, cmd, NULL);
 	if (reclist) {
@@ -125,5 +139,6 @@ gnome_db_browser_tables_clear (GtkWidget *widget)
 	if (!priv)
 		return;
 
+	gnome_db_grid_set_model (GNOME_DB_GRID (priv->table_struct), NULL);
 	gnome_db_grid_set_model (GNOME_DB_GRID (priv->data_grid), NULL);
 }
