@@ -45,7 +45,7 @@ struct _GnomeDbBrowserPrivate {
 		GtkWidget *object_list;
 		GtkWidget *object_detail;
 		gboolean data_retrieved;
-	} objects_info [4];
+	} objects_info [6];
 };
 
 static void gnome_db_browser_class_init   (GnomeDbBrowserClass *klass);
@@ -66,6 +66,12 @@ enum {
 	PROP_CONNECTION
 };
 
+enum {
+	PROGRESS_MESSAGE,
+	LAST_SIGNAL
+};
+
+static gint browser_signals[LAST_SIGNAL];
 static GObjectClass *parent_class = NULL;
 
 /*
@@ -103,8 +109,11 @@ table_selected_cb (GnomeDbList *list, gint row, gpointer user_data)
 		return;
 
 	str = gda_value_get_string ((GdaValue *) value);
+	g_signal_emit (G_OBJECT (browser), browser_signals[PROGRESS_MESSAGE],
+		       0, _("Loading table data..."));
 	gnome_db_browser_tables_show (browser->priv->objects_info[0].object_detail,
 				      browser->priv->cnc, str);
+	g_signal_emit (G_OBJECT (browser), browser_signals[PROGRESS_MESSAGE], 0, NULL);
 }
 
 static void
@@ -113,10 +122,42 @@ table_selection_cleared_cb (GnomeDbList *list, gpointer user_data)
 	GnomeDbBrowser *browser = (GnomeDbBrowser *) user_data;
 
 	g_return_if_fail (GNOME_DB_IS_BROWSER (browser));
-
 	gnome_db_browser_tables_clear (browser->priv->objects_info[0].object_detail);
 }
 
+static void
+view_selected_cb (GnomeDbList *list, gint row, gpointer user_data)
+{
+	GdaDataModel *model;
+	const GdaValue *value;
+	const gchar *str;
+	GnomeDbBrowser *browser = (GnomeDbBrowser *) user_data;
+
+	g_return_if_fail (GNOME_DB_IS_BROWSER (browser));
+
+	model = gnome_db_list_get_model (
+		GNOME_DB_LIST (browser->priv->objects_info[2].object_list));
+	value = gda_data_model_get_value_at (model, 0, row);
+	if (!value)
+		return;
+
+	str = gda_value_get_string ((GdaValue *) value);
+	g_signal_emit (G_OBJECT (browser), browser_signals[PROGRESS_MESSAGE],
+		       0, _("Loading view data..."));
+	gnome_db_browser_views_show (browser->priv->objects_info[2].object_detail,
+				     browser->priv->cnc, str);
+	g_signal_emit (G_OBJECT (browser), browser_signals[PROGRESS_MESSAGE], 0, NULL);
+}
+
+static void
+view_selection_cleared_cb (GnomeDbList *list, gpointer user_data)
+{
+	GnomeDbBrowser *browser = (GnomeDbBrowser *) user_data;
+
+	g_return_if_fail (GNOME_DB_IS_BROWSER (browser));
+	gnome_db_browser_views_clear (browser->priv->objects_info[2].object_detail);
+}
+
 /*
  * Private functions
  */
@@ -166,6 +207,11 @@ initialize_object_widgets (GnomeDbBrowser *browser)
 	browser->priv->objects_info[2].data_retrieved = FALSE;
 
 	browser->priv->objects_info[2].object_list = gnome_db_list_new ();
+	g_signal_connect (G_OBJECT (browser->priv->objects_info[2].object_list),
+			  "row_selected", G_CALLBACK (view_selected_cb), browser);
+	g_signal_connect (G_OBJECT (browser->priv->objects_info[2].object_list),
+			  "selection_cleared", G_CALLBACK (view_selection_cleared_cb),
+			  browser);
 	gtk_notebook_append_page (GTK_NOTEBOOK (browser->priv->object_notebook),
 				  browser->priv->objects_info[2].object_list,
 				  gtk_label_new (_("Views")));
@@ -190,6 +236,36 @@ initialize_object_widgets (GnomeDbBrowser *browser)
 	gtk_notebook_append_page (GTK_NOTEBOOK (browser->priv->detail_notebook),
 				  browser->priv->objects_info[3].object_detail,
 				  gtk_label_new (_("Procedures")));
+
+	/* initialize aggregate widgets */
+	browser->priv->objects_info[4].schema = GDA_CONNECTION_SCHEMA_AGGREGATES;
+	browser->priv->objects_info[4].data_retrieved = FALSE;
+
+	browser->priv->objects_info[4].object_list = gnome_db_list_new ();
+	gtk_notebook_append_page (GTK_NOTEBOOK (browser->priv->object_notebook),
+				  browser->priv->objects_info[4].object_list,
+				  gtk_label_new (_("Aggregates")));
+	gtk_widget_show (browser->priv->objects_info[4].object_list);
+
+	browser->priv->objects_info[4].object_detail = gnome_db_new_label_widget ("TODO");
+	gtk_notebook_append_page (GTK_NOTEBOOK (browser->priv->detail_notebook),
+	                          browser->priv->objects_info[4].object_detail,
+				  gtk_label_new (_("Aggregates")));
+
+	/* initialize trigger widgets */
+	browser->priv->objects_info[5].schema = GDA_CONNECTION_SCHEMA_TRIGGERS;
+	browser->priv->objects_info[5].data_retrieved = FALSE;
+
+	browser->priv->objects_info[5].object_list = gnome_db_list_new ();
+	gtk_notebook_append_page (GTK_NOTEBOOK (browser->priv->object_notebook),
+				  browser->priv->objects_info[5].object_list,
+				  gtk_label_new (_("Triggers")));
+	gtk_widget_show (browser->priv->objects_info[5].object_list);
+
+	browser->priv->objects_info[5].object_detail = gnome_db_new_label_widget ("TODO");
+	gtk_notebook_append_page (GTK_NOTEBOOK (browser->priv->detail_notebook),
+	                          browser->priv->objects_info[5].object_detail,
+				  gtk_label_new (_("Triggers")));
 }
 
 /*
@@ -213,6 +289,16 @@ gnome_db_browser_class_init (GnomeDbBrowserClass *klass)
 		g_param_spec_object ("connection", NULL, NULL,
 				     GDA_TYPE_CONNECTION,
 				     (G_PARAM_READABLE | G_PARAM_WRITABLE)));
+
+	/* add class signals */
+	browser_signals[PROGRESS_MESSAGE] =
+		g_signal_new ("progress_message",
+			      G_TYPE_FROM_CLASS (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (GnomeDbBrowserClass, progress_message),
+			      NULL, NULL,
+			      g_cclosure_marshal_VOID__STRING,
+			      G_TYPE_NONE, 1, G_TYPE_STRING);
 }
 
 static void
@@ -379,6 +465,9 @@ gnome_db_browser_set_connection (GnomeDbBrowser *browser, GdaConnection *cnc)
 
 	g_return_if_fail (GNOME_DB_IS_BROWSER (browser));
 
+	g_signal_emit (G_OBJECT (browser), browser_signals[PROGRESS_MESSAGE],
+		       0, _("Loading database schemas..."));
+
 	/* clear the current setup */
 	if (GDA_IS_CONNECTION (browser->priv->cnc)) {
 		g_object_unref (G_OBJECT (browser->priv->cnc));
@@ -396,6 +485,9 @@ gnome_db_browser_set_connection (GnomeDbBrowser *browser, GdaConnection *cnc)
 		case GDA_CONNECTION_SCHEMA_TABLES :
 			gnome_db_browser_tables_clear (browser->priv->objects_info[n].object_detail);
 			break;
+		case GDA_CONNECTION_SCHEMA_VIEWS :
+			gnome_db_browser_views_clear (browser->priv->objects_info[n].object_detail);
+			break;
 		default :
 		}
 	}
@@ -416,7 +508,54 @@ gnome_db_browser_set_connection (GnomeDbBrowser *browser, GdaConnection *cnc)
 		gnome_db_list_set_model (
 		     GNOME_DB_LIST (browser->priv->objects_info[n].object_list),
 		     recset, 0);
+		browser->priv->objects_info[n].data_retrieved = TRUE;
 
 		g_object_unref (G_OBJECT (recset));
 	}
+
+	g_signal_emit (G_OBJECT (browser), browser_signals[PROGRESS_MESSAGE], 0, NULL);
+}
+
+/**
+ * gnome_db_browser_refresh
+ * @browser: a #GnomeDbBrowser widget.
+ *
+ * Make the browser widget refresh its currently displayed data.
+ */
+void
+gnome_db_browser_refresh (GnomeDbBrowser *browser)
+{
+	gint current;
+	GdaDataModel *recset;
+
+	g_return_if_fail (GNOME_DB_IS_BROWSER (browser));
+
+	g_signal_emit (G_OBJECT (browser), browser_signals[PROGRESS_MESSAGE],
+		       0, _("Refreshing data..."));
+	current = gtk_notebook_get_current_page (
+		GTK_NOTEBOOK (browser->priv->object_notebook));
+
+	/* refresh the object list */
+	recset = gda_connection_get_schema (
+			browser->priv->cnc,
+			browser->priv->objects_info[current].schema,
+			NULL);
+	gnome_db_list_set_model (
+		GNOME_DB_LIST (browser->priv->objects_info[current].object_list),
+		recset, 0);
+	browser->priv->objects_info[current].data_retrieved = TRUE;
+	g_object_unref (G_OBJECT (recset));
+
+	/* clear the detail widget */
+	switch (browser->priv->objects_info[current].schema) {
+	case GDA_CONNECTION_SCHEMA_TABLES :
+		gnome_db_browser_tables_clear (browser->priv->objects_info[current].object_detail);
+		break;
+	case GDA_CONNECTION_SCHEMA_VIEWS :
+		gnome_db_browser_views_clear (browser->priv->objects_info[current].object_detail);
+		break;
+	default :
+	}
+
+	g_signal_emit (G_OBJECT (browser), browser_signals[PROGRESS_MESSAGE], 0, NULL);
 }
