@@ -103,7 +103,7 @@ gnome_db_data_source_selector_finalize (GObject *object)
 	g_free (selector->priv);
 	selector->priv = NULL;
 
-	parent_class->finalize;
+	parent_class->finalize (object);
 }
 
 GType
