@@ -128,6 +128,8 @@ gnome_db_list_init (GnomeDbList *list, GnomeDbListClass *klass)
 
 	/* set up widgets */
 	list->priv->grid = gnome_db_new_grid_widget (NULL);
+	gnome_db_grid_set_selection_mode (GNOME_DB_GRID (list->priv->grid),
+					  GTK_SELECTION_SINGLE);
 	g_signal_connect (G_OBJECT (list->priv->grid), "row_selected",
 			  G_CALLBACK (grid_row_selected_cb), list);
 	g_signal_connect (G_OBJECT (list->priv->grid), "selection_cleared",
