@@ -1,5 +1,5 @@
 /* GNOME DB library
- * Copyright (C) 1999-2001, The Free Software Foundation
+ * Copyright (C) 1999-2002 The GNOME Foundation.
  *
  * AUTHORS:
  *      Rodrigo Moya <rodrigo@gnome-db.org>
@@ -20,13 +20,12 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
-
+#include <gtk/gtkstock.h>
 #include <libgnomedb/gnome-db-login.h>
 #include <libgnomedb/gnome-db-login-dialog.h>
-
+#include <libgnomedb/gnome-db-stock.h>
+#include <libgnomeui/gnome-window-icon.h>
 #include "gnome-db-intl.h"
 
 struct _GnomeDbLoginDialogPrivate {
@@ -89,8 +88,8 @@ gnome_db_login_dialog_init (GnomeDbLoginDialog *dialog, GnomeDbLoginDialogClass
 
 	dialog->priv = g_new0 (GnomeDbLoginDialogPrivate, 1);
 
-	gtk_dialog_add_button (GTK_DIALOG (dialog), _("Cancel"), GTK_RESPONSE_CANCEL);
-	gtk_dialog_add_button (GTK_DIALOG (dialog), _("OK"), GTK_RESPONSE_OK);
+	gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
+	gtk_dialog_add_button (GTK_DIALOG (dialog), GNOME_DB_STOCK_CONNECT, GTK_RESPONSE_OK);
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 
 	dialog->priv->login = gnome_db_login_new (NULL);
@@ -194,6 +193,8 @@ gnome_db_login_dialog_new (const gchar *title)
 
 	dialog = g_object_new (GNOME_DB_TYPE_LOGIN_DIALOG, NULL);
 	gtk_window_set_title (GTK_WINDOW (dialog), title);
+	gnome_window_icon_set_from_file (GTK_WINDOW (dialog),
+					 LIBGNOMEDB_PIXMAPSDIR "/gnome-db.png");
 
 	return GTK_WIDGET (dialog);
 }
