@@ -40,6 +40,7 @@ GtkWidget   *gnome_db_new_button_widget_from_stock (const gchar *stock_id);
 GtkWidget   *gnome_db_new_check_button_widget (const gchar *label);
 GtkWidget   *gnome_db_new_combo_widget (void);
 GtkWidget   *gnome_db_new_entry_widget (gint max_length, gboolean editable);
+GtkWidget   *gnome_db_new_file_entry_widget (const gchar *history_id, const gchar *title);
 GtkWidget   *gnome_db_new_frame_widget (const gchar *title);
 GtkWidget   *gnome_db_new_grid_widget (GdaDataModel *model);
 GtkWidget   *gnome_db_new_hbox_widget (gboolean homogenous, gint spacing);
@@ -52,6 +53,7 @@ GtkWidget   *gnome_db_new_option_menu_widget (void);
 GtkWidget   *gnome_db_new_popup_menu (GtkWidget *parent,
 				      GnomeUIInfo *ui_info,
 				      gpointer user_data);
+GtkWidget   *gnome_db_new_radio_button_widget (GSList *group, const gchar *label);
 GtkWidget   *gnome_db_new_scrolled_window_widget (void);
 GtkWidget   *gnome_db_new_status_bar_widget (void);
 GtkWidget   *gnome_db_new_table_widget (gint rows, gint cols, gboolean homogenous);
@@ -60,6 +62,7 @@ GtkWidget   *gnome_db_new_toolbar_widget (GtkOrientation orientation, GtkToolbar
 GtkWidget   *gnome_db_new_tree_view_widget (GtkTreeModel *model);
 GtkWidget   *gnome_db_new_vbox_widget (gboolean homogenous, gint spacing);
 GtkWidget   *gnome_db_new_vpaned_widget (void);
+GtkWidget   *gnome_db_new_vseparator_widget (void);
 
 void         gnome_db_set_widget_bg_color (GtkWidget *widget, const gchar *color);
 void         gnome_db_set_widget_fg_color (GtkWidget *widget, const gchar *color);
